"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: ac9b961cc70d

from .basesdk import BaseSDK
from mistralai.client import errors, models, utils
from mistralai.client._hooks import HookContext
from mistralai.client.types import OptionalNullable, UNSET
from mistralai.client.utils import eventstreaming, get_security_from_env
from mistralai.client.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, Dict, List, Mapping, Optional


class Events(BaseSDK):
    def get_stream_events(
        self,
        *,
        scope: Optional[models.Scope] = "*",
        activity_name: Optional[str] = "*",
        activity_id: Optional[str] = "*",
        workflow_name: Optional[str] = "*",
        workflow_exec_id: Optional[str] = "*",
        root_workflow_exec_id: Optional[str] = "*",
        parent_workflow_exec_id: Optional[str] = "*",
        stream: Optional[str] = "*",
        start_seq: Optional[int] = 0,
        metadata_filters: OptionalNullable[Dict[str, Any]] = UNSET,
        workflow_event_types: OptionalNullable[List[models.WorkflowEventType]] = UNSET,
        last_event_id: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> eventstreaming.EventStream[
        models.GetStreamEventsV1WorkflowsEventsStreamGetResponseBody
    ]:
        r"""Get Stream Events

        :param scope:
        :param activity_name:
        :param activity_id:
        :param workflow_name:
        :param workflow_exec_id:
        :param root_workflow_exec_id:
        :param parent_workflow_exec_id:
        :param stream:
        :param start_seq:
        :param metadata_filters:
        :param workflow_event_types:
        :param last_event_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetStreamEventsV1WorkflowsEventsStreamGetRequest(
            scope=scope,
            activity_name=activity_name,
            activity_id=activity_id,
            workflow_name=workflow_name,
            workflow_exec_id=workflow_exec_id,
            root_workflow_exec_id=root_workflow_exec_id,
            parent_workflow_exec_id=parent_workflow_exec_id,
            stream=stream,
            start_seq=start_seq,
            metadata_filters=metadata_filters,
            workflow_event_types=workflow_event_types,
            last_event_id=last_event_id,
        )

        req = self._build_request(
            method="GET",
            path="/v1/workflows/events/stream",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="text/event-stream",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="get_stream_events_v1_workflows_events_stream_get",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            stream=True,
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "text/event-stream"):
            return eventstreaming.EventStream(
                http_res,
                lambda raw: utils.unmarshal_json(
                    raw, models.GetStreamEventsV1WorkflowsEventsStreamGetResponseBody
                ),
                client_ref=self,
                data_required=False,
            )
        if utils.match_response(http_res, "422", "application/json"):
            http_res_text = utils.stream_to_text(http_res)
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res, http_res_text
            )
            raise errors.HTTPValidationError(response_data, http_res, http_res_text)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        http_res_text = utils.stream_to_text(http_res)
        raise errors.SDKError("Unexpected response received", http_res, http_res_text)

    async def get_stream_events_async(
        self,
        *,
        scope: Optional[models.Scope] = "*",
        activity_name: Optional[str] = "*",
        activity_id: Optional[str] = "*",
        workflow_name: Optional[str] = "*",
        workflow_exec_id: Optional[str] = "*",
        root_workflow_exec_id: Optional[str] = "*",
        parent_workflow_exec_id: Optional[str] = "*",
        stream: Optional[str] = "*",
        start_seq: Optional[int] = 0,
        metadata_filters: OptionalNullable[Dict[str, Any]] = UNSET,
        workflow_event_types: OptionalNullable[List[models.WorkflowEventType]] = UNSET,
        last_event_id: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> eventstreaming.EventStreamAsync[
        models.GetStreamEventsV1WorkflowsEventsStreamGetResponseBody
    ]:
        r"""Get Stream Events

        :param scope:
        :param activity_name:
        :param activity_id:
        :param workflow_name:
        :param workflow_exec_id:
        :param root_workflow_exec_id:
        :param parent_workflow_exec_id:
        :param stream:
        :param start_seq:
        :param metadata_filters:
        :param workflow_event_types:
        :param last_event_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetStreamEventsV1WorkflowsEventsStreamGetRequest(
            scope=scope,
            activity_name=activity_name,
            activity_id=activity_id,
            workflow_name=workflow_name,
            workflow_exec_id=workflow_exec_id,
            root_workflow_exec_id=root_workflow_exec_id,
            parent_workflow_exec_id=parent_workflow_exec_id,
            stream=stream,
            start_seq=start_seq,
            metadata_filters=metadata_filters,
            workflow_event_types=workflow_event_types,
            last_event_id=last_event_id,
        )

        req = self._build_request_async(
            method="GET",
            path="/v1/workflows/events/stream",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="text/event-stream",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="get_stream_events_v1_workflows_events_stream_get",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            stream=True,
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "text/event-stream"):
            return eventstreaming.EventStreamAsync(
                http_res,
                lambda raw: utils.unmarshal_json(
                    raw, models.GetStreamEventsV1WorkflowsEventsStreamGetResponseBody
                ),
                client_ref=self,
                data_required=False,
            )
        if utils.match_response(http_res, "422", "application/json"):
            http_res_text = await utils.stream_to_text_async(http_res)
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res, http_res_text
            )
            raise errors.HTTPValidationError(response_data, http_res, http_res_text)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        http_res_text = await utils.stream_to_text_async(http_res)
        raise errors.SDKError("Unexpected response received", http_res, http_res_text)

    def get_workflow_events(
        self,
        *,
        root_workflow_exec_id: OptionalNullable[str] = UNSET,
        workflow_exec_id: OptionalNullable[str] = UNSET,
        workflow_run_id: OptionalNullable[str] = UNSET,
        limit: Optional[int] = 100,
        cursor: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ListWorkflowEventResponse:
        r"""Get Workflow Events

        :param root_workflow_exec_id: Execution ID of the root workflow that initiated this execution chain.
        :param workflow_exec_id: Execution ID of the workflow that emitted this event.
        :param workflow_run_id: Run ID of the workflow that emitted this event.
        :param limit: Maximum number of events to return.
        :param cursor: Cursor for pagination.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetWorkflowEventsV1WorkflowsEventsListGetRequest(
            root_workflow_exec_id=root_workflow_exec_id,
            workflow_exec_id=workflow_exec_id,
            workflow_run_id=workflow_run_id,
            limit=limit,
            cursor=cursor,
        )

        req = self._build_request(
            method="GET",
            path="/v1/workflows/events/list",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="get_workflow_events_v1_workflows_events_list_get",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.ListWorkflowEventResponse, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        raise errors.SDKError("Unexpected response received", http_res)

    async def get_workflow_events_async(
        self,
        *,
        root_workflow_exec_id: OptionalNullable[str] = UNSET,
        workflow_exec_id: OptionalNullable[str] = UNSET,
        workflow_run_id: OptionalNullable[str] = UNSET,
        limit: Optional[int] = 100,
        cursor: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ListWorkflowEventResponse:
        r"""Get Workflow Events

        :param root_workflow_exec_id: Execution ID of the root workflow that initiated this execution chain.
        :param workflow_exec_id: Execution ID of the workflow that emitted this event.
        :param workflow_run_id: Run ID of the workflow that emitted this event.
        :param limit: Maximum number of events to return.
        :param cursor: Cursor for pagination.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetWorkflowEventsV1WorkflowsEventsListGetRequest(
            root_workflow_exec_id=root_workflow_exec_id,
            workflow_exec_id=workflow_exec_id,
            workflow_run_id=workflow_run_id,
            limit=limit,
            cursor=cursor,
        )

        req = self._build_request_async(
            method="GET",
            path="/v1/workflows/events/list",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="get_workflow_events_v1_workflows_events_list_get",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.ListWorkflowEventResponse, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        raise errors.SDKError("Unexpected response received", http_res)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 2445f12b2a57

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing import Dict
from typing_extensions import TypedDict


class ClassificationTargetResultTypedDict(TypedDict):
    scores: Dict[str, float]


class ClassificationTargetResult(BaseModel):
    scores: Dict[str, float]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 7a8ed2e90d61

from .basesdk import BaseSDK
from .sdkconfiguration import SDKConfiguration
from mistralai.client.speech import Speech
from mistralai.client.transcriptions import Transcriptions
from mistralai.client.voices import Voices
from typing import Optional

# region imports
from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from mistralai.extra.realtime import RealtimeTranscription
# endregion imports


class Audio(BaseSDK):
    speech: Speech
    transcriptions: Transcriptions
    r"""API for audio transcription."""
    voices: Voices

    def __init__(
        self, sdk_config: SDKConfiguration, parent_ref: Optional[object] = None
    ) -> None:
        BaseSDK.__init__(self, sdk_config, parent_ref=parent_ref)
        self.sdk_configuration = sdk_config
        self._init_sdks()

    def _init_sdks(self):
        self.speech = Speech(self.sdk_configuration, parent_ref=self.parent_ref)
        self.transcriptions = Transcriptions(
            self.sdk_configuration, parent_ref=self.parent_ref
        )
        self.voices = Voices(self.sdk_configuration, parent_ref=self.parent_ref)

    # region sdk-class-body
    @property
    def realtime(self) -> "RealtimeTranscription":
        """Returns a client for real-time audio transcription via WebSocket."""
        if not hasattr(self, "_realtime"):
            from mistralai.extra.realtime import RealtimeTranscription  # pylint: disable=import-outside-toplevel

            self._realtime = RealtimeTranscription(self.sdk_configuration)  # pylint: disable=attribute-defined-outside-init

        return self._realtime

    # endregion sdk-class-body



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 399da05bd75e

from __future__ import annotations
from .voiceupdaterequest import VoiceUpdateRequest, VoiceUpdateRequestTypedDict
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateVoiceV1AudioVoicesVoiceIDPatchRequestTypedDict(TypedDict):
    voice_id: str
    voice_update_request: VoiceUpdateRequestTypedDict


class UpdateVoiceV1AudioVoicesVoiceIDPatchRequest(BaseModel):
    voice_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    voice_update_request: Annotated[
        VoiceUpdateRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 046a094d3ef9

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class CreateDatasetRequestTypedDict(TypedDict):
    name: str
    description: str


class CreateDatasetRequest(BaseModel):
    name: str

    description: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 8b926028b7b2

from __future__ import annotations
from typing import Literal


EventSource = Literal[
    "DATABASE",
    "LIVE",
]



from .basesdk import BaseSDK
from .httpclient import AsyncHttpClient, ClientOwner, HttpClient, close_clients
from .sdkconfiguration import SDKConfiguration
from .utils.logger import Logger, get_default_logger
from .utils.retries import RetryConfig
import httpx
import importlib
import logging
from mistralai.azure.client import models, utils
from mistralai.azure.client._hooks import SDKHooks
from mistralai.azure.client.types import OptionalNullable, UNSET
import sys
from typing import Callable, Dict, Optional, TYPE_CHECKING, Union, cast
import warnings
import weakref

logger = logging.getLogger(__name__)

if TYPE_CHECKING:
    from mistralai.azure.client.chat import Chat
    from mistralai.azure.client.ocr import Ocr


class MistralAzure(BaseSDK):
    r"""Mistral AI API: Dora OpenAPI schema

    Our Chat Completion and Embeddings APIs specification. Create your account on [La Plateforme](https://console.mistral.ai) to get access and read the [docs](https://docs.mistral.ai) to learn how to use it.
    """

    chat: "Chat"
    r"""Chat Completion API."""
    ocr: "Ocr"
    _sub_sdk_map = {
        "chat": ("mistralai.azure.client.chat", "Chat"),
        "ocr": ("mistralai.azure.client.ocr", "Ocr"),
    }

    def __init__(
        self,
        api_key: Union[str, Callable[[], str]],
        server: Optional[str] = None,
        server_url: Optional[str] = None,
        url_params: Optional[Dict[str, str]] = None,
        client: Optional[HttpClient] = None,
        async_client: Optional[AsyncHttpClient] = None,
        retry_config: OptionalNullable[RetryConfig] = UNSET,
        timeout_ms: Optional[int] = None,
        debug_logger: Optional[Logger] = None,
        api_version: str = "2024-05-01-preview",
    ) -> None:
        r"""Instantiates the SDK configuring it with the provided parameters.

        :param api_key: The api_key required for authentication
        :param server: The server by name to use for all methods
        :param server_url: The server URL to use for all methods
        :param url_params: Parameters to optionally template the server URL with
        :param client: The HTTP client to use for all synchronous methods
        :param async_client: The Async HTTP client to use for all asynchronous methods
        :param retry_config: The retry configuration to use for all supported methods
        :param timeout_ms: Optional request timeout applied to each operation in milliseconds
        :param api_version: Azure API version to use (injected as query param)
        """
        client_supplied = True
        if client is None:
            client = httpx.Client(
                follow_redirects=True,
                params={"api-version": api_version},
            )
            client_supplied = False
        elif api_version != "2024-05-01-preview":
            warnings.warn(
                "api_version is ignored when a custom client is provided. "
                "Set the api-version query parameter on your httpx.Client directly.",
                stacklevel=2,
            )

        assert issubclass(
            type(client), HttpClient
        ), "The provided client must implement the HttpClient protocol."

        async_client_supplied = True
        if async_client is None:
            async_client = httpx.AsyncClient(
                follow_redirects=True,
                params={"api-version": api_version},
            )
            async_client_supplied = False
        elif api_version != "2024-05-01-preview":
            warnings.warn(
                "api_version is ignored when a custom async_client is provided. "
                "Set the api-version query parameter on your httpx.AsyncClient directly.",
                stacklevel=2,
            )

        if debug_logger is None:
            debug_logger = get_default_logger()

        assert issubclass(
            type(async_client), AsyncHttpClient
        ), "The provided async_client must implement the AsyncHttpClient protocol."

        security: Union[models.Security, Callable[[], models.Security]]
        if callable(api_key):

            def get_security() -> models.Security:
                return models.Security(api_key=api_key())

            security = get_security
        else:
            security = models.Security(api_key=api_key)

        if server_url is not None:
            if url_params is not None:
                server_url = utils.template_url(server_url, url_params)

        BaseSDK.__init__(
            self,
            SDKConfiguration(
                client=client,
                client_supplied=client_supplied,
                async_client=async_client,
                async_client_supplied=async_client_supplied,
                security=security,
                server_url=server_url,
                server=server,
                retry_config=retry_config,
                timeout_ms=timeout_ms,
                debug_logger=debug_logger,
            ),
            parent_ref=self,
        )

        hooks = SDKHooks()
        self.sdk_configuration.__dict__["_hooks"] = hooks

        current_server_url, *_ = self.sdk_configuration.get_server_details()
        server_url, self.sdk_configuration.client = hooks.sdk_init(
            current_server_url, client
        )
        if current_server_url != server_url:
            self.sdk_configuration.server_url = server_url

        weakref.finalize(
            self,
            close_clients,
            cast(ClientOwner, self.sdk_configuration),
            self.sdk_configuration.client,
            self.sdk_configuration.client_supplied,
            self.sdk_configuration.async_client,
            self.sdk_configuration.async_client_supplied,
        )

    def dynamic_import(self, modname, retries=3):
        last_exc: Optional[Exception] = None
        for attempt in range(retries):
            try:
                return importlib.import_module(modname)
            except (KeyError, ImportError, ModuleNotFoundError) as e:
                last_exc = e
                # Clear any half-initialized module and retry
                sys.modules.pop(modname, None)
                if attempt == retries - 1:
                    break
        raise ImportError(
            f"Failed to import module '{modname}' after {retries} attempts"
        ) from last_exc

    def __getattr__(self, name: str):
        if name in self._sub_sdk_map:
            module_path, class_name = self._sub_sdk_map[name]
            try:
                module = self.dynamic_import(module_path)
                klass = getattr(module, class_name)
                instance = klass(self.sdk_configuration, parent_ref=self)
                setattr(self, name, instance)
                return instance
            except ImportError as e:
                raise AttributeError(
                    f"Failed to import module {module_path} for attribute {name}: {e}"
                ) from e
            except AttributeError as e:
                raise AttributeError(
                    f"Failed to find class {class_name} in module {module_path} for attribute {name}: {e}"
                ) from e

        raise AttributeError(
            f"'{type(self).__name__}' object has no attribute '{name}'"
        )

    def __dir__(self):
        default_attrs = list(super().__dir__())
        lazy_attrs = list(self._sub_sdk_map.keys())
        return sorted(list(set(default_attrs + lazy_attrs)))

    def __enter__(self):
        return self

    async def __aenter__(self):
        return self

    def __exit__(self, _exc_type, _exc_val, _exc_tb):
        if (
            self.sdk_configuration.client is not None
            and not self.sdk_configuration.client_supplied
        ):
            self.sdk_configuration.client.close()
        self.sdk_configuration.client = None

    async def __aexit__(self, _exc_type, _exc_val, _exc_tb):
        if (
            self.sdk_configuration.async_client is not None
            and not self.sdk_configuration.async_client_supplied
        ):
            await self.sdk_configuration.async_client.aclose()
        self.sdk_configuration.async_client = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 3fae92e2573a

from __future__ import annotations
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class GetDeploymentV1WorkflowsDeploymentsNameGetRequestTypedDict(TypedDict):
    name: str


class GetDeploymentV1WorkflowsDeploymentsNameGetRequest(BaseModel):
    name: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .contentchunk import ContentChunk, ContentChunkTypedDict
from .toolcall import ToolCall, ToolCallTypedDict
from mistralai.gcp.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from mistralai.gcp.client.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import List, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


AssistantMessageContentTypedDict = TypeAliasType(
    "AssistantMessageContentTypedDict", Union[str, List[ContentChunkTypedDict]]
)


AssistantMessageContent = TypeAliasType(
    "AssistantMessageContent", Union[str, List[ContentChunk]]
)


class AssistantMessageTypedDict(TypedDict):
    role: Literal["assistant"]
    content: NotRequired[Nullable[AssistantMessageContentTypedDict]]
    tool_calls: NotRequired[Nullable[List[ToolCallTypedDict]]]
    prefix: NotRequired[bool]
    r"""Set this to `true` when adding an assistant message as prefix to condition the model response. The role of the prefix message is to force the model to start its answer by the content of the message."""


class AssistantMessage(BaseModel):
    role: Annotated[
        Annotated[
            Optional[Literal["assistant"]], AfterValidator(validate_const("assistant"))
        ],
        pydantic.Field(alias="role"),
    ] = "assistant"

    content: OptionalNullable[AssistantMessageContent] = UNSET

    tool_calls: OptionalNullable[List[ToolCall]] = UNSET

    prefix: Optional[bool] = False
    r"""Set this to `true` when adding an assistant message as prefix to condition the model response. The role of the prefix message is to force the model to start its answer by the content of the message."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["role", "content", "tool_calls", "prefix"])
        nullable_fields = set(["content", "tool_calls"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


try:
    AssistantMessage.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: ab76b1377d79

from .basesdk import BaseSDK
from mistralai.client import errors, models, utils
from mistralai.client._hooks import HookContext
from mistralai.client.types import OptionalNullable, UNSET
from mistralai.client.utils import get_security_from_env
from mistralai.client.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, List, Mapping, Optional


class Voices(BaseSDK):
    def list(
        self,
        *,
        limit: Optional[int] = 10,
        offset: Optional[int] = 0,
        type_: Optional[models.ListVoicesV1AudioVoicesGetType] = "all",
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.VoiceListResponse:
        r"""List all voices

        List all voices (excluding sample data)

        :param limit: Maximum number of voices to return
        :param offset: Offset for pagination
        :param type: Filter the voices between customs and presets
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListVoicesV1AudioVoicesGetRequest(
            limit=limit,
            offset=offset,
            type=type_,
        )

        req = self._build_request(
            method="GET",
            path="/v1/audio/voices",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="list_voices_v1_audio_voices_get",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.VoiceListResponse, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        raise errors.SDKError("Unexpected response received", http_res)

    async def list_async(
        self,
        *,
        limit: Optional[int] = 10,
        offset: Optional[int] = 0,
        type_: Optional[models.ListVoicesV1AudioVoicesGetType] = "all",
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.VoiceListResponse:
        r"""List all voices

        List all voices (excluding sample data)

        :param limit: Maximum number of voices to return
        :param offset: Offset for pagination
        :param type: Filter the voices between customs and presets
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListVoicesV1AudioVoicesGetRequest(
            limit=limit,
            offset=offset,
            type=type_,
        )

        req = self._build_request_async(
            method="GET",
            path="/v1/audio/voices",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="list_voices_v1_audio_voices_get",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.VoiceListResponse, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        raise errors.SDKError("Unexpected response received", http_res)

    def create(
        self,
        *,
        name: str,
        sample_audio: str,
        slug: OptionalNullable[str] = UNSET,
        languages: Optional[List[str]] = None,
        gender: OptionalNullable[str] = UNSET,
        age: OptionalNullable[int] = UNSET,
        tags: OptionalNullable[List[str]] = UNSET,
        color: OptionalNullable[str] = UNSET,
        retention_notice: Optional[int] = 30,
        sample_filename: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.VoiceResponse:
        r"""Create a new voice

        Create a new voice with a base64-encoded audio sample

        :param name:
        :param sample_audio: Base64-encoded audio file
        :param slug:
        :param languages:
        :param gender:
        :param age:
        :param tags:
        :param color:
        :param retention_notice:
        :param sample_filename: Original filename for extension detection
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.VoiceCreateRequest(
            name=name,
            slug=slug,
            languages=languages,
            gender=gender,
            age=age,
            tags=tags,
            color=color,
            retention_notice=retention_notice,
            sample_audio=sample_audio,
            sample_filename=sample_filename,
        )

        req = self._build_request(
            method="POST",
            path="/v1/audio/voices",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.VoiceCreateRequest
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="create_voice_v1_audio_voices_post",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.VoiceResponse, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        raise errors.SDKError("Unexpected response received", http_res)

    async def create_async(
        self,
        *,
        name: str,
        sample_audio: str,
        slug: OptionalNullable[str] = UNSET,
        languages: Optional[List[str]] = None,
        gender: OptionalNullable[str] = UNSET,
        age: OptionalNullable[int] = UNSET,
        tags: OptionalNullable[List[str]] = UNSET,
        color: OptionalNullable[str] = UNSET,
        retention_notice: Optional[int] = 30,
        sample_filename: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.VoiceResponse:
        r"""Create a new voice

        Create a new voice with a base64-encoded audio sample

        :param name:
        :param sample_audio: Base64-encoded audio file
        :param slug:
        :param languages:
        :param gender:
        :param age:
        :param tags:
        :param color:
        :param retention_notice:
        :param sample_filename: Original filename for extension detection
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.VoiceCreateRequest(
            name=name,
            slug=slug,
            languages=languages,
            gender=gender,
            age=age,
            tags=tags,
            color=color,
            retention_notice=retention_notice,
            sample_audio=sample_audio,
            sample_filename=sample_filename,
        )

        req = self._build_request_async(
            method="POST",
            path="/v1/audio/voices",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.VoiceCreateRequest
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="create_voice_v1_audio_voices_post",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.VoiceResponse, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        raise errors.SDKError("Unexpected response received", http_res)

    def delete(
        self,
        *,
        voice_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.VoiceResponse:
        r"""Delete a custom voice

        Delete a custom voice

        :param voice_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.DeleteVoiceV1AudioVoicesVoiceIDDeleteRequest(
            voice_id=voice_id,
        )

        req = self._build_request(
            method="DELETE",
            path="/v1/audio/voices/{voice_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="delete_voice_v1_audio_voices__voice_id__delete",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.VoiceResponse, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        raise errors.SDKError("Unexpected response received", http_res)

    async def delete_async(
        self,
        *,
        voice_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.VoiceResponse:
        r"""Delete a custom voice

        Delete a custom voice

        :param voice_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.DeleteVoiceV1AudioVoicesVoiceIDDeleteRequest(
            voice_id=voice_id,
        )

        req = self._build_request_async(
            method="DELETE",
            path="/v1/audio/voices/{voice_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="delete_voice_v1_audio_voices__voice_id__delete",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.VoiceResponse, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        raise errors.SDKError("Unexpected response received", http_res)

    def update(
        self,
        *,
        voice_id: str,
        name: OptionalNullable[str] = UNSET,
        languages: OptionalNullable[List[str]] = UNSET,
        gender: OptionalNullable[str] = UNSET,
        age: OptionalNullable[int] = UNSET,
        tags: OptionalNullable[List[str]] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.VoiceResponse:
        r"""Update voice metadata

        Update voice metadata (name, gender, languages, age, tags).

        :param voice_id:
        :param name:
        :param languages:
        :param gender:
        :param age:
        :param tags:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.UpdateVoiceV1AudioVoicesVoiceIDPatchRequest(
            voice_id=voice_id,
            voice_update_request=models.VoiceUpdateRequest(
                name=name,
                languages=languages,
                gender=gender,
                age=age,
                tags=tags,
            ),
        )

        req = self._build_request(
            method="PATCH",
            path="/v1/audio/voices/{voice_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.voice_update_request,
                False,
                False,
                "json",
                models.VoiceUpdateRequest,
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="update_voice_v1_audio_voices__voice_id__patch",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.VoiceResponse, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        raise errors.SDKError("Unexpected response received", http_res)

    async def update_async(
        self,
        *,
        voice_id: str,
        name: OptionalNullable[str] = UNSET,
        languages: OptionalNullable[List[str]] = UNSET,
        gender: OptionalNullable[str] = UNSET,
        age: OptionalNullable[int] = UNSET,
        tags: OptionalNullable[List[str]] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.VoiceResponse:
        r"""Update voice metadata

        Update voice metadata (name, gender, languages, age, tags).

        :param voice_id:
        :param name:
        :param languages:
        :param gender:
        :param age:
        :param tags:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.UpdateVoiceV1AudioVoicesVoiceIDPatchRequest(
            voice_id=voice_id,
            voice_update_request=models.VoiceUpdateRequest(
                name=name,
                languages=languages,
                gender=gender,
                age=age,
                tags=tags,
            ),
        )

        req = self._build_request_async(
            method="PATCH",
            path="/v1/audio/voices/{voice_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.voice_update_request,
                False,
                False,
                "json",
                models.VoiceUpdateRequest,
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="update_voice_v1_audio_voices__voice_id__patch",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.VoiceResponse, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        raise errors.SDKError("Unexpected response received", http_res)

    def get(
        self,
        *,
        voice_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.VoiceResponse:
        r"""Get voice details

        Get voice details (excluding sample)

        :param voice_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetVoiceV1AudioVoicesVoiceIDGetRequest(
            voice_id=voice_id,
        )

        req = self._build_request(
            method="GET",
            path="/v1/audio/voices/{voice_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="get_voice_v1_audio_voices__voice_id__get",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.VoiceResponse, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        raise errors.SDKError("Unexpected response received", http_res)

    async def get_async(
        self,
        *,
        voice_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.VoiceResponse:
        r"""Get voice details

        Get voice details (excluding sample)

        :param voice_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetVoiceV1AudioVoicesVoiceIDGetRequest(
            voice_id=voice_id,
        )

        req = self._build_request_async(
            method="GET",
            path="/v1/audio/voices/{voice_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="get_voice_v1_audio_voices__voice_id__get",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.VoiceResponse, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        raise errors.SDKError("Unexpected response received", http_res)

    def get_sample_audio(
        self,
        *,
        voice_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> str:
        r"""Get voice sample audio

        Get the audio sample for a voice

        :param voice_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetVoiceSampleAudioV1AudioVoicesVoiceIDSampleGetRequest(
            voice_id=voice_id,
        )

        req = self._build_request(
            method="GET",
            path="/v1/audio/voices/{voice_id}/sample",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="get_voice_sample_audio_v1_audio_voices__voice_id__sample_get",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(str, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        raise errors.SDKError("Unexpected response received", http_res)

    async def get_sample_audio_async(
        self,
        *,
        voice_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> str:
        r"""Get voice sample audio

        Get the audio sample for a voice

        :param voice_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetVoiceSampleAudioV1AudioVoicesVoiceIDSampleGetRequest(
            voice_id=voice_id,
        )

        req = self._build_request_async(
            method="GET",
            path="/v1/audio/voices/{voice_id}/sample",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="get_voice_sample_audio_v1_audio_voices__voice_id__sample_get",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(str, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        raise errors.SDKError("Unexpected response received", http_res)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: e4148b4d23e7

from __future__ import annotations
from .file import File, FileTypedDict
from .timestampgranularity import TimestampGranularity
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from mistralai.client.utils import FieldMetadata, MultipartFormMetadata, validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import List, Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class AudioTranscriptionRequestTypedDict(TypedDict):
    model: str
    r"""ID of the model to be used."""
    file: NotRequired[FileTypedDict]
    file_url: NotRequired[Nullable[str]]
    r"""Url of a file to be transcribed"""
    file_id: NotRequired[Nullable[str]]
    r"""ID of a file uploaded to /v1/files"""
    language: NotRequired[Nullable[str]]
    r"""Language of the audio, e.g. 'en'. Providing the language can boost accuracy."""
    temperature: NotRequired[Nullable[float]]
    stream: Literal[False]
    diarize: NotRequired[bool]
    context_bias: NotRequired[List[str]]
    timestamp_granularities: NotRequired[List[TimestampGranularity]]
    r"""Granularities of timestamps to include in the response."""


class AudioTranscriptionRequest(BaseModel):
    model: Annotated[str, FieldMetadata(multipart=True)]
    r"""ID of the model to be used."""

    file: Annotated[
        Optional[File], FieldMetadata(multipart=MultipartFormMetadata(file=True))
    ] = None

    file_url: Annotated[OptionalNullable[str], FieldMetadata(multipart=True)] = UNSET
    r"""Url of a file to be transcribed"""

    file_id: Annotated[OptionalNullable[str], FieldMetadata(multipart=True)] = UNSET
    r"""ID of a file uploaded to /v1/files"""

    language: Annotated[OptionalNullable[str], FieldMetadata(multipart=True)] = UNSET
    r"""Language of the audio, e.g. 'en'. Providing the language can boost accuracy."""

    temperature: Annotated[OptionalNullable[float], FieldMetadata(multipart=True)] = (
        UNSET
    )

    stream: Annotated[
        Annotated[Optional[Literal[False]], AfterValidator(validate_const(False))],
        pydantic.Field(alias="stream"),
        FieldMetadata(multipart=True),
    ] = False

    diarize: Annotated[Optional[bool], FieldMetadata(multipart=True)] = False

    context_bias: Annotated[Optional[List[str]], FieldMetadata(multipart=True)] = None

    timestamp_granularities: Annotated[
        Optional[List[TimestampGranularity]], FieldMetadata(multipart=True)
    ] = None
    r"""Granularities of timestamps to include in the response."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "file",
                "file_url",
                "file_id",
                "language",
                "temperature",
                "stream",
                "diarize",
                "context_bias",
                "timestamp_granularities",
            ]
        )
        nullable_fields = set(["file_url", "file_id", "language", "temperature"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


try:
    AudioTranscriptionRequest.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: bb55993c932d

from __future__ import annotations
from .updateagentrequest import UpdateAgentRequest, UpdateAgentRequestTypedDict
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class AgentsAPIV1AgentsUpdateRequestTypedDict(TypedDict):
    agent_id: str
    update_agent_request: UpdateAgentRequestTypedDict


class AgentsAPIV1AgentsUpdateRequest(BaseModel):
    agent_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    update_agent_request: Annotated[
        UpdateAgentRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 36f204c64074

from __future__ import annotations
from .documenturlchunk import DocumentURLChunk, DocumentURLChunkTypedDict
from .filechunk import FileChunk, FileChunkTypedDict
from .imageurlchunk import ImageURLChunk, ImageURLChunkTypedDict
from .responseformat import ResponseFormat, ResponseFormatTypedDict
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Literal, Optional, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


DocumentUnionTypedDict = TypeAliasType(
    "DocumentUnionTypedDict",
    Union[FileChunkTypedDict, ImageURLChunkTypedDict, DocumentURLChunkTypedDict],
)
r"""Document to run OCR on"""


DocumentUnion = TypeAliasType(
    "DocumentUnion", Union[FileChunk, ImageURLChunk, DocumentURLChunk]
)
r"""Document to run OCR on"""


TableFormat = Literal[
    "markdown",
    "html",
]


class OCRRequestTypedDict(TypedDict):
    model: Nullable[str]
    document: DocumentUnionTypedDict
    r"""Document to run OCR on"""
    id: NotRequired[str]
    pages: NotRequired[Nullable[List[int]]]
    r"""Specific pages user wants to process in various formats: single number, range, or list of both. Starts from 0"""
    include_image_base64: NotRequired[Nullable[bool]]
    r"""Include image URLs in response"""
    image_limit: NotRequired[Nullable[int]]
    r"""Max images to extract"""
    image_min_size: NotRequired[Nullable[int]]
    r"""Minimum height and width of image to extract"""
    bbox_annotation_format: NotRequired[Nullable[ResponseFormatTypedDict]]
    r"""Structured output class for extracting useful information from each extracted bounding box / image from document. Only json_schema is valid for this field"""
    document_annotation_format: NotRequired[Nullable[ResponseFormatTypedDict]]
    r"""Structured output class for extracting useful information from the entire document. Only json_schema is valid for this field"""
    document_annotation_prompt: NotRequired[Nullable[str]]
    r"""Optional prompt to guide the model in extracting structured output from the entire document. A document_annotation_format must be provided."""
    table_format: NotRequired[Nullable[TableFormat]]
    extract_header: NotRequired[bool]
    extract_footer: NotRequired[bool]


class OCRRequest(BaseModel):
    model: Nullable[str]

    document: DocumentUnion
    r"""Document to run OCR on"""

    id: Optional[str] = None

    pages: OptionalNullable[List[int]] = UNSET
    r"""Specific pages user wants to process in various formats: single number, range, or list of both. Starts from 0"""

    include_image_base64: OptionalNullable[bool] = UNSET
    r"""Include image URLs in response"""

    image_limit: OptionalNullable[int] = UNSET
    r"""Max images to extract"""

    image_min_size: OptionalNullable[int] = UNSET
    r"""Minimum height and width of image to extract"""

    bbox_annotation_format: OptionalNullable[ResponseFormat] = UNSET
    r"""Structured output class for extracting useful information from each extracted bounding box / image from document. Only json_schema is valid for this field"""

    document_annotation_format: OptionalNullable[ResponseFormat] = UNSET
    r"""Structured output class for extracting useful information from the entire document. Only json_schema is valid for this field"""

    document_annotation_prompt: OptionalNullable[str] = UNSET
    r"""Optional prompt to guide the model in extracting structured output from the entire document. A document_annotation_format must be provided."""

    table_format: OptionalNullable[TableFormat] = UNSET

    extract_header: Optional[bool] = None

    extract_footer: Optional[bool] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "id",
                "pages",
                "include_image_base64",
                "image_limit",
                "image_min_size",
                "bbox_annotation_format",
                "document_annotation_format",
                "document_annotation_prompt",
                "table_format",
                "extract_header",
                "extract_footer",
            ]
        )
        nullable_fields = set(
            [
                "model",
                "pages",
                "include_image_base64",
                "image_limit",
                "image_min_size",
                "bbox_annotation_format",
                "document_annotation_format",
                "document_annotation_prompt",
                "table_format",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai.azure.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing_extensions import NotRequired, TypedDict


class OCRImageObjectTypedDict(TypedDict):
    id: str
    r"""Image ID for extracted image in a page"""
    top_left_x: Nullable[int]
    r"""X coordinate of top-left corner of the extracted image"""
    top_left_y: Nullable[int]
    r"""Y coordinate of top-left corner of the extracted image"""
    bottom_right_x: Nullable[int]
    r"""X coordinate of bottom-right corner of the extracted image"""
    bottom_right_y: Nullable[int]
    r"""Y coordinate of bottom-right corner of the extracted image"""
    image_base64: NotRequired[Nullable[str]]
    r"""Base64 string of the extracted image"""
    image_annotation: NotRequired[Nullable[str]]
    r"""Annotation of the extracted image in json str"""


class OCRImageObject(BaseModel):
    id: str
    r"""Image ID for extracted image in a page"""

    top_left_x: Nullable[int]
    r"""X coordinate of top-left corner of the extracted image"""

    top_left_y: Nullable[int]
    r"""Y coordinate of top-left corner of the extracted image"""

    bottom_right_x: Nullable[int]
    r"""X coordinate of bottom-right corner of the extracted image"""

    bottom_right_y: Nullable[int]
    r"""Y coordinate of bottom-right corner of the extracted image"""

    image_base64: OptionalNullable[str] = UNSET
    r"""Base64 string of the extracted image"""

    image_annotation: OptionalNullable[str] = UNSET
    r"""Annotation of the extracted image in json str"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["image_base64", "image_annotation"])
        nullable_fields = set(
            [
                "top_left_x",
                "top_left_y",
                "bottom_right_x",
                "bottom_right_y",
                "image_base64",
                "image_annotation",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 3db008bcddca

from __future__ import annotations
from .completionargsstop import CompletionArgsStop, CompletionArgsStopTypedDict
from .prediction import Prediction, PredictionTypedDict
from .reasoningeffort import ReasoningEffort
from .responseformat import ResponseFormat, ResponseFormatTypedDict
from .toolchoiceenum import ToolChoiceEnum
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CompletionArgsTypedDict(TypedDict):
    r"""White-listed arguments from the completion API"""

    stop: NotRequired[Nullable[CompletionArgsStopTypedDict]]
    presence_penalty: NotRequired[Nullable[float]]
    frequency_penalty: NotRequired[Nullable[float]]
    temperature: NotRequired[Nullable[float]]
    top_p: NotRequired[Nullable[float]]
    max_tokens: NotRequired[Nullable[int]]
    random_seed: NotRequired[Nullable[int]]
    prediction: NotRequired[Nullable[PredictionTypedDict]]
    response_format: NotRequired[Nullable[ResponseFormatTypedDict]]
    tool_choice: NotRequired[ToolChoiceEnum]
    reasoning_effort: NotRequired[Nullable[ReasoningEffort]]


class CompletionArgs(BaseModel):
    r"""White-listed arguments from the completion API"""

    stop: OptionalNullable[CompletionArgsStop] = UNSET

    presence_penalty: OptionalNullable[float] = UNSET

    frequency_penalty: OptionalNullable[float] = UNSET

    temperature: OptionalNullable[float] = UNSET

    top_p: OptionalNullable[float] = UNSET

    max_tokens: OptionalNullable[int] = UNSET

    random_seed: OptionalNullable[int] = UNSET

    prediction: OptionalNullable[Prediction] = UNSET

    response_format: OptionalNullable[ResponseFormat] = UNSET

    tool_choice: Optional[ToolChoiceEnum] = None

    reasoning_effort: OptionalNullable[ReasoningEffort] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "stop",
                "presence_penalty",
                "frequency_penalty",
                "temperature",
                "top_p",
                "max_tokens",
                "random_seed",
                "prediction",
                "response_format",
                "tool_choice",
                "reasoning_effort",
            ]
        )
        nullable_fields = set(
            [
                "stop",
                "presence_penalty",
                "frequency_penalty",
                "temperature",
                "top_p",
                "max_tokens",
                "random_seed",
                "prediction",
                "response_format",
                "reasoning_effort",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 6b388bc155dd

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class MessageResponseTypedDict(TypedDict):
    message: str


class MessageResponse(BaseModel):
    message: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 40c697c1e617

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


TempoTraceScopeKind = Union[
    Literal[
        "SPAN_KIND_INTERNAL",
        "SPAN_KIND_SERVER",
        "SPAN_KIND_CLIENT",
    ],
    UnrecognizedStr,
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: ae572b470a30

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


ObservabilityErrorCode = Union[
    Literal[
        "UNKNOWN_ERROR",
        "VALIDATION_ERROR",
        "AUTH_FORBIDDEN",
        "AUTH_FORBIDDEN_NOT_WORKSPACE_ADMIN",
        "AUTH_FORBIDDEN_WORKSPACE_NOT_FOUND",
        "AUTH_FORBIDDEN_ROLE_NOT_FOUND",
        "AUTH_FORBIDDEN_ORG_NOT_WHITELISTED",
        "AUTH_UNAUTHORIZED",
        "FEATURE_NOT_SUPPORTED",
        "FIELDS_BAD_REQUEST",
        "FIELDS_NOT_FOUND",
        "SEARCH_NOT_FOUND",
        "SEARCH_BAD_REQUEST",
        "SEARCH_SERVICE_UNAVAILABLE",
        "DATABASE_ERROR",
        "DATABASE_TIMEOUT",
        "DATABASE_UNAVAILABLE",
        "DATABASE_QUERY_ERROR",
        "SEARCH_FILTER_TO_SQL_CONVERSION_ERROR",
        "JUDGE_CONVERSATION_FORMAT_ERROR",
        "JUDGE_MISTRAL_API_ERROR",
        "JUDGE_MISTRAL_API_TIMEOUT",
        "JUDGE_NAME_ALREADY_EXISTS",
        "JUDGE_NOT_FOUND",
        "JUDGE_ALREADY_HAS_NEW_VERSION",
        "JUDGE_USED_IN_CAMPAIGN_CANNOT_BE_UPDATED",
        "JUDGE_DID_NOT_CHANGE",
        "CAMPAIGN_NOT_FOUND",
        "CAMPAIGN_NO_MATCHING_EVENTS",
        "DATASET_NOT_FOUND",
        "DATASET_TASK_NOT_FOUND",
        "DATASET_RECORD_NOT_FOUND",
        "DATASET_RECORD_FORMAT_ERROR",
        "AGENT_NOT_FOUND",
        "AGENT_MISTRAL_API_ERROR",
        "EVALUATION_NOT_FOUND",
        "EVALUATION_CURRENTLY_RUNNING",
        "EVALUATION_RECORD_NOT_FOUND",
        "EVALUATION_RUN_NOT_FOUND",
        "EVALUATION_RUN_TRANSITION_IS_INVALID",
        "EVALUATION_RUN_TRANSITION_IS_RUNNING_ALREADY",
        "EVALUATION_RUN_TRANSITION_ERROR",
        "TEMPLATE_SYNTAX_ERROR",
    ],
    UnrecognizedStr,
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 56e24cd24e98

from __future__ import annotations
from .apiendpoint import APIEndpoint
from .batchrequest import BatchRequest, BatchRequestTypedDict
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import Dict, List, Optional
from typing_extensions import NotRequired, TypedDict


class CreateBatchJobRequestTypedDict(TypedDict):
    endpoint: APIEndpoint
    input_files: NotRequired[Nullable[List[str]]]
    r"""The list of input files to be used for batch inference, these files should be `jsonl` files, containing the input data corresponding to the bory request for the batch inference in a \"body\" field. An example of such file is the following: ```json {\"custom_id\": \"0\", \"body\": {\"max_tokens\": 100, \"messages\": [{\"role\": \"user\", \"content\": \"What is the best French cheese?\"}]}} {\"custom_id\": \"1\", \"body\": {\"max_tokens\": 100, \"messages\": [{\"role\": \"user\", \"content\": \"What is the best French wine?\"}]}} ```"""
    requests: NotRequired[Nullable[List[BatchRequestTypedDict]]]
    model: NotRequired[Nullable[str]]
    r"""The model to be used for batch inference."""
    agent_id: NotRequired[Nullable[str]]
    r"""In case you want to use a specific agent from the **deprecated** agents api for batch inference, you can specify the agent ID here."""
    metadata: NotRequired[Nullable[Dict[str, str]]]
    r"""The metadata of your choice to be associated with the batch inference job."""
    timeout_hours: NotRequired[int]
    r"""The timeout in hours for the batch inference job."""


class CreateBatchJobRequest(BaseModel):
    endpoint: APIEndpoint

    input_files: OptionalNullable[List[str]] = UNSET
    r"""The list of input files to be used for batch inference, these files should be `jsonl` files, containing the input data corresponding to the bory request for the batch inference in a \"body\" field. An example of such file is the following: ```json {\"custom_id\": \"0\", \"body\": {\"max_tokens\": 100, \"messages\": [{\"role\": \"user\", \"content\": \"What is the best French cheese?\"}]}} {\"custom_id\": \"1\", \"body\": {\"max_tokens\": 100, \"messages\": [{\"role\": \"user\", \"content\": \"What is the best French wine?\"}]}} ```"""

    requests: OptionalNullable[List[BatchRequest]] = UNSET

    model: OptionalNullable[str] = UNSET
    r"""The model to be used for batch inference."""

    agent_id: OptionalNullable[str] = UNSET
    r"""In case you want to use a specific agent from the **deprecated** agents api for batch inference, you can specify the agent ID here."""

    metadata: OptionalNullable[Dict[str, str]] = UNSET
    r"""The metadata of your choice to be associated with the batch inference job."""

    timeout_hours: Optional[int] = 24
    r"""The timeout in hours for the batch inference job."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "input_files",
                "requests",
                "model",
                "agent_id",
                "metadata",
                "timeout_hours",
            ]
        )
        nullable_fields = set(
            ["input_files", "requests", "model", "agent_id", "metadata"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 6ea7078aaca3

from __future__ import annotations
from .eventprogressstatus import EventProgressStatus
from .eventtype import EventType
from .workflowexecutiontracesummaryattributesvalues import (
    WorkflowExecutionTraceSummaryAttributesValues,
    WorkflowExecutionTraceSummaryAttributesValuesTypedDict,
)
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class WorkflowExecutionProgressTraceEventTypedDict(TypedDict):
    name: str
    r"""Name of the event"""
    id: str
    r"""The ID of the event"""
    timestamp_unix_nano: int
    r"""The timestamp of the event in nanoseconds since the Unix epoch"""
    attributes: Dict[
        str, Nullable[WorkflowExecutionTraceSummaryAttributesValuesTypedDict]
    ]
    r"""The attributes of the event"""
    start_time_unix_ms: int
    r"""The start time of the event in milliseconds since the Unix epoch"""
    type: NotRequired[EventType]
    internal: NotRequired[bool]
    r"""Whether the event is internal"""
    status: NotRequired[EventProgressStatus]
    end_time_unix_ms: NotRequired[Nullable[int]]
    r"""The end time of the event in milliseconds since the Unix epoch"""
    error: NotRequired[Nullable[str]]
    r"""The error message, if any"""


class WorkflowExecutionProgressTraceEvent(BaseModel):
    name: str
    r"""Name of the event"""

    id: str
    r"""The ID of the event"""

    timestamp_unix_nano: int
    r"""The timestamp of the event in nanoseconds since the Unix epoch"""

    attributes: Dict[str, Nullable[WorkflowExecutionTraceSummaryAttributesValues]]
    r"""The attributes of the event"""

    start_time_unix_ms: int
    r"""The start time of the event in milliseconds since the Unix epoch"""

    type: Optional[EventType] = None

    internal: Optional[bool] = False
    r"""Whether the event is internal"""

    status: Optional[EventProgressStatus] = None

    end_time_unix_ms: OptionalNullable[int] = UNSET
    r"""The end time of the event in milliseconds since the Unix epoch"""

    error: OptionalNullable[str] = UNSET
    r"""The error message, if any"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["type", "internal", "status", "end_time_unix_ms", "error"]
        )
        nullable_fields = set(["end_time_unix_ms", "error"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: be26cd87dcb3

from __future__ import annotations
from .workflowexecutioncontinuedasnewattributesresponse import (
    WorkflowExecutionContinuedAsNewAttributesResponse,
    WorkflowExecutionContinuedAsNewAttributesResponseTypedDict,
)
from mistralai.client.types import BaseModel, Nullable, UNSET_SENTINEL
from mistralai.client.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Literal, Optional
from typing_extensions import Annotated, TypedDict


class WorkflowExecutionContinuedAsNewResponseTypedDict(TypedDict):
    r"""Emitted when a workflow continues as a new execution.

    This occurs when a workflow uses continue-as-new to reset its history
    while maintaining logical continuity.
    """

    event_id: str
    r"""Unique identifier for this event instance."""
    event_timestamp: int
    r"""Unix timestamp in nanoseconds when the event was created."""
    root_workflow_exec_id: str
    r"""Execution ID of the root workflow that initiated this execution chain."""
    parent_workflow_exec_id: Nullable[str]
    r"""Execution ID of the parent workflow that initiated this execution. If this is a root workflow, this field is not set."""
    workflow_exec_id: str
    r"""Execution ID of the workflow that emitted this event."""
    workflow_run_id: str
    r"""Run ID of the workflow execution. Changes on continue-as-new while workflow_exec_id stays the same."""
    workflow_name: str
    r"""The registered name of the workflow that emitted this event."""
    attributes: WorkflowExecutionContinuedAsNewAttributesResponseTypedDict
    r"""Attributes for workflow execution continued-as-new events."""
    event_type: Literal["WORKFLOW_EXECUTION_CONTINUED_AS_NEW"]
    r"""Event type discriminator."""


class WorkflowExecutionContinuedAsNewResponse(BaseModel):
    r"""Emitted when a workflow continues as a new execution.

    This occurs when a workflow uses continue-as-new to reset its history
    while maintaining logical continuity.
    """

    event_id: str
    r"""Unique identifier for this event instance."""

    event_timestamp: int
    r"""Unix timestamp in nanoseconds when the event was created."""

    root_workflow_exec_id: str
    r"""Execution ID of the root workflow that initiated this execution chain."""

    parent_workflow_exec_id: Nullable[str]
    r"""Execution ID of the parent workflow that initiated this execution. If this is a root workflow, this field is not set."""

    workflow_exec_id: str
    r"""Execution ID of the workflow that emitted this event."""

    workflow_run_id: str
    r"""Run ID of the workflow execution. Changes on continue-as-new while workflow_exec_id stays the same."""

    workflow_name: str
    r"""The registered name of the workflow that emitted this event."""

    attributes: WorkflowExecutionContinuedAsNewAttributesResponse
    r"""Attributes for workflow execution continued-as-new events."""

    event_type: Annotated[
        Annotated[
            Optional[Literal["WORKFLOW_EXECUTION_CONTINUED_AS_NEW"]],
            AfterValidator(validate_const("WORKFLOW_EXECUTION_CONTINUED_AS_NEW")),
        ],
        pydantic.Field(alias="event_type"),
    ] = "WORKFLOW_EXECUTION_CONTINUED_AS_NEW"
    r"""Event type discriminator."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["event_type"])
        nullable_fields = set(["parent_workflow_exec_id"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


try:
    WorkflowExecutionContinuedAsNewResponse.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: b4aeeb03b57a

from __future__ import annotations
from typing import Literal


WorkflowEventType = Literal[
    "WORKFLOW_EXECUTION_STARTED",
    "WORKFLOW_EXECUTION_COMPLETED",
    "WORKFLOW_EXECUTION_FAILED",
    "WORKFLOW_EXECUTION_CANCELED",
    "WORKFLOW_EXECUTION_CONTINUED_AS_NEW",
    "WORKFLOW_TASK_TIMED_OUT",
    "WORKFLOW_TASK_FAILED",
    "CUSTOM_TASK_STARTED",
    "CUSTOM_TASK_IN_PROGRESS",
    "CUSTOM_TASK_COMPLETED",
    "CUSTOM_TASK_FAILED",
    "CUSTOM_TASK_TIMED_OUT",
    "CUSTOM_TASK_CANCELED",
    "ACTIVITY_TASK_STARTED",
    "ACTIVITY_TASK_COMPLETED",
    "ACTIVITY_TASK_RETRYING",
    "ACTIVITY_TASK_FAILED",
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: fa5d55a9d6cf

from __future__ import annotations
from .updatedatasetrecordpayloadrequest import (
    UpdateDatasetRecordPayloadRequest,
    UpdateDatasetRecordPayloadRequestTypedDict,
)
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateDatasetRecordPayloadV1ObservabilityDatasetRecordsDatasetRecordIDPayloadPutRequestTypedDict(
    TypedDict
):
    dataset_record_id: str
    update_dataset_record_payload_request: UpdateDatasetRecordPayloadRequestTypedDict


class UpdateDatasetRecordPayloadV1ObservabilityDatasetRecordsDatasetRecordIDPayloadPutRequest(
    BaseModel
):
    dataset_record_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    update_dataset_record_payload_request: Annotated[
        UpdateDatasetRecordPayloadRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 3899a98a55dd

from __future__ import annotations
from datetime import datetime
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class AgentAliasResponseTypedDict(TypedDict):
    alias: str
    version: int
    created_at: datetime
    updated_at: datetime


class AgentAliasResponse(BaseModel):
    alias: str

    version: int

    created_at: datetime

    updated_at: datetime



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 862335210b20

from .basesdk import BaseSDK
from mistralai.client import errors, models, utils
from mistralai.client._hooks import HookContext
from mistralai.client.types import OptionalNullable, UNSET
from mistralai.client.utils import get_security_from_env
from mistralai.client.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, Mapping, Optional, Union


class Fields(BaseSDK):
    def list(
        self,
        *,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ListChatCompletionFieldsResponse:
        r"""Get Chat Completion Fields

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        req = self._build_request(
            method="GET",
            path="/v1/observability/chat-completion-fields",
            base_url=base_url,
            url_variables=url_variables,
            request=None,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="get_chat_completion_fields_v1_observability_chat_completion_fields_get",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "404", "408", "409", "422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.ListChatCompletionFieldsResponse, http_res
            )
        if utils.match_response(
            http_res, ["400", "404", "408", "409", "422"], "application/json"
        ):
            response_data = unmarshal_json_response(
                errors.ObservabilityErrorData, http_res
            )
            raise errors.ObservabilityError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        raise errors.SDKError("Unexpected response received", http_res)

    async def list_async(
        self,
        *,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ListChatCompletionFieldsResponse:
        r"""Get Chat Completion Fields

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        req = self._build_request_async(
            method="GET",
            path="/v1/observability/chat-completion-fields",
            base_url=base_url,
            url_variables=url_variables,
            request=None,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="get_chat_completion_fields_v1_observability_chat_completion_fields_get",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "404", "408", "409", "422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.ListChatCompletionFieldsResponse, http_res
            )
        if utils.match_response(
            http_res, ["400", "404", "408", "409", "422"], "application/json"
        ):
            response_data = unmarshal_json_response(
                errors.ObservabilityErrorData, http_res
            )
            raise errors.ObservabilityError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        raise errors.SDKError("Unexpected response received", http_res)

    def fetch_options(
        self,
        *,
        field_name: str,
        operator: models.Operator,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.FetchChatCompletionFieldOptionsResponse:
        r"""Get Chat Completion Field Options

        :param field_name:
        :param operator: The operator to use for filtering options
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetChatCompletionFieldOptionsV1ObservabilityChatCompletionFieldsFieldNameOptionsGetRequest(
            field_name=field_name,
            operator=operator,
        )

        req = self._build_request(
            method="GET",
            path="/v1/observability/chat-completion-fields/{field_name}/options",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="get_chat_completion_field_options_v1_observability_chat_completion_fields__field_name__options_get",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "404", "408", "409", "422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.FetchChatCompletionFieldOptionsResponse, http_res
            )
        if utils.match_response(
            http_res, ["400", "404", "408", "409", "422"], "application/json"
        ):
            response_data = unmarshal_json_response(
                errors.ObservabilityErrorData, http_res
            )
            raise errors.ObservabilityError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        raise errors.SDKError("Unexpected response received", http_res)

    async def fetch_options_async(
        self,
        *,
        field_name: str,
        operator: models.Operator,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.FetchChatCompletionFieldOptionsResponse:
        r"""Get Chat Completion Field Options

        :param field_name:
        :param operator: The operator to use for filtering options
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetChatCompletionFieldOptionsV1ObservabilityChatCompletionFieldsFieldNameOptionsGetRequest(
            field_name=field_name,
            operator=operator,
        )

        req = self._build_request_async(
            method="GET",
            path="/v1/observability/chat-completion-fields/{field_name}/options",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="get_chat_completion_field_options_v1_observability_chat_completion_fields__field_name__options_get",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "404", "408", "409", "422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.FetchChatCompletionFieldOptionsResponse, http_res
            )
        if utils.match_response(
            http_res, ["400", "404", "408", "409", "422"], "application/json"
        ):
            response_data = unmarshal_json_response(
                errors.ObservabilityErrorData, http_res
            )
            raise errors.ObservabilityError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        raise errors.SDKError("Unexpected response received", http_res)

    def fetch_option_counts(
        self,
        *,
        field_name: str,
        filter_params: OptionalNullable[
            Union[models.FilterPayload, models.FilterPayloadTypedDict]
        ] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.FetchFieldOptionCountsResponse:
        r"""Get Chat Completion Field Options Counts

        :param field_name:
        :param filter_params:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetChatCompletionFieldOptionsCountsV1ObservabilityChatCompletionFieldsFieldNameOptionsCountsPostRequest(
            field_name=field_name,
            fetch_field_option_counts_request=models.FetchFieldOptionCountsRequest(
                filter_params=utils.get_pydantic_model(
                    filter_params, OptionalNullable[models.FilterPayload]
                ),
            ),
        )

        req = self._build_request(
            method="POST",
            path="/v1/observability/chat-completion-fields/{field_name}/options-counts",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.fetch_field_option_counts_request,
                False,
                False,
                "json",
                models.FetchFieldOptionCountsRequest,
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="get_chat_completion_field_options_counts_v1_observability_chat_completion_fields__field_name__options_counts_post",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "404", "408", "409", "422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.FetchFieldOptionCountsResponse, http_res
            )
        if utils.match_response(
            http_res, ["400", "404", "408", "409", "422"], "application/json"
        ):
            response_data = unmarshal_json_response(
                errors.ObservabilityErrorData, http_res
            )
            raise errors.ObservabilityError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        raise errors.SDKError("Unexpected response received", http_res)

    async def fetch_option_counts_async(
        self,
        *,
        field_name: str,
        filter_params: OptionalNullable[
            Union[models.FilterPayload, models.FilterPayloadTypedDict]
        ] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.FetchFieldOptionCountsResponse:
        r"""Get Chat Completion Field Options Counts

        :param field_name:
        :param filter_params:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetChatCompletionFieldOptionsCountsV1ObservabilityChatCompletionFieldsFieldNameOptionsCountsPostRequest(
            field_name=field_name,
            fetch_field_option_counts_request=models.FetchFieldOptionCountsRequest(
                filter_params=utils.get_pydantic_model(
                    filter_params, OptionalNullable[models.FilterPayload]
                ),
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/v1/observability/chat-completion-fields/{field_name}/options-counts",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.fetch_field_option_counts_request,
                False,
                False,
                "json",
                models.FetchFieldOptionCountsRequest,
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="get_chat_completion_field_options_counts_v1_observability_chat_completion_fields__field_name__options_counts_post",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "404", "408", "409", "422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.FetchFieldOptionCountsResponse, http_res
            )
        if utils.match_response(
            http_res, ["400", "404", "408", "409", "422"], "application/json"
        ):
            response_data = unmarshal_json_response(
                errors.ObservabilityErrorData, http_res
            )
            raise errors.ObservabilityError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        raise errors.SDKError("Unexpected response received", http_res)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 247ebe411537

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing import Dict
from typing_extensions import TypedDict


class ConnectorToolLocaleTypedDict(TypedDict):
    name: Dict[str, str]
    description: Dict[str, str]
    usage_sentence: Dict[str, str]


class ConnectorToolLocale(BaseModel):
    name: Dict[str, str]

    description: Dict[str, str]

    usage_sentence: Dict[str, str]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .imagedetail import ImageDetail
from mistralai.gcp.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing_extensions import NotRequired, TypedDict


class ImageURLTypedDict(TypedDict):
    url: str
    detail: NotRequired[Nullable[ImageDetail]]


class ImageURL(BaseModel):
    url: str

    detail: OptionalNullable[ImageDetail] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["detail"])
        nullable_fields = set(["detail"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 48edbcb38d7e

from .basesdk import BaseSDK
from .httpclient import AsyncHttpClient, ClientOwner, HttpClient, close_clients
from .sdkconfiguration import SDKConfiguration
from .utils.logger import Logger, get_default_logger
from .utils.retries import RetryConfig
import httpx
import importlib
from mistralai.client import models as models_, utils
from mistralai.client._hooks import SDKHooks
from mistralai.client.types import OptionalNullable, UNSET
import sys
from typing import Any, Callable, Dict, Optional, TYPE_CHECKING, Union, cast
import weakref

if TYPE_CHECKING:
    from mistralai.client.agents import Agents
    from mistralai.client.audio import Audio
    from mistralai.client.batch import Batch
    from mistralai.client.beta import Beta
    from mistralai.client.chat import Chat
    from mistralai.client.classifiers import Classifiers
    from mistralai.client.embeddings import Embeddings
    from mistralai.client.events import Events
    from mistralai.client.files import Files
    from mistralai.client.fim import Fim
    from mistralai.client.fine_tuning import FineTuning
    from mistralai.client.models_ import Models
    from mistralai.client.ocr import Ocr
    from mistralai.client.workflows import Workflows


class Mistral(BaseSDK):
    r"""Mistral AI API: Our Chat Completion and Embeddings APIs specification. Create your account on [La Plateforme](https://console.mistral.ai) to get access and read the [docs](https://docs.mistral.ai) to learn how to use it."""

    audio: "Audio"
    models: "Models"
    r"""Model Management API"""
    beta: "Beta"
    files: "Files"
    r"""Files API"""
    fine_tuning: "FineTuning"
    batch: "Batch"
    chat: "Chat"
    r"""Chat Completion API."""
    fim: "Fim"
    r"""Fill-in-the-middle API."""
    agents: "Agents"
    r"""Agents API."""
    embeddings: "Embeddings"
    r"""Embeddings API."""
    classifiers: "Classifiers"
    r"""Classifiers API."""
    ocr: "Ocr"
    r"""OCR API"""
    workflows: "Workflows"
    events: "Events"
    _sub_sdk_map = {
        "audio": ("mistralai.client.audio", "Audio"),
        "models": ("mistralai.client.models_", "Models"),
        "beta": ("mistralai.client.beta", "Beta"),
        "files": ("mistralai.client.files", "Files"),
        "fine_tuning": ("mistralai.client.fine_tuning", "FineTuning"),
        "batch": ("mistralai.client.batch", "Batch"),
        "chat": ("mistralai.client.chat", "Chat"),
        "fim": ("mistralai.client.fim", "Fim"),
        "agents": ("mistralai.client.agents", "Agents"),
        "embeddings": ("mistralai.client.embeddings", "Embeddings"),
        "classifiers": ("mistralai.client.classifiers", "Classifiers"),
        "ocr": ("mistralai.client.ocr", "Ocr"),
        "workflows": ("mistralai.client.workflows", "Workflows"),
        "events": ("mistralai.client.events", "Events"),
    }

    def __init__(
        self,
        api_key: Optional[Union[Optional[str], Callable[[], Optional[str]]]] = None,
        server: Optional[str] = None,
        url_params: Optional[Dict[str, str]] = None,
        server_url: Optional[str] = None,
        client: Optional[HttpClient] = None,
        async_client: Optional[AsyncHttpClient] = None,
        retry_config: OptionalNullable[RetryConfig] = UNSET,
        timeout_ms: Optional[int] = None,
        debug_logger: Optional[Logger] = None,
    ) -> None:
        r"""Instantiates the SDK configuring it with the provided parameters.

        :param api_key: The api_key required for authentication
        :param server: The server by name to use for all methods
        :param server_url: The server URL to use for all methods
        :param url_params: Parameters to optionally template the server URL with
        :param client: The HTTP client to use for all synchronous methods
        :param async_client: The Async HTTP client to use for all asynchronous methods
        :param retry_config: The retry configuration to use for all supported methods
        :param timeout_ms: Optional request timeout applied to each operation in milliseconds
        """
        client_supplied = True
        if client is None:
            client = httpx.Client(follow_redirects=True)
            client_supplied = False

        assert issubclass(
            type(client), HttpClient
        ), "The provided client must implement the HttpClient protocol."

        async_client_supplied = True
        if async_client is None:
            async_client = httpx.AsyncClient(follow_redirects=True)
            async_client_supplied = False

        if debug_logger is None:
            debug_logger = get_default_logger()

        assert issubclass(
            type(async_client), AsyncHttpClient
        ), "The provided async_client must implement the AsyncHttpClient protocol."

        security: Any = None
        if callable(api_key):
            # pylint: disable=unnecessary-lambda-assignment
            security = lambda: models_.Security(api_key=api_key())
        else:
            security = models_.Security(api_key=api_key)

        if server_url is not None:
            if url_params is not None:
                server_url = utils.template_url(server_url, url_params)

        BaseSDK.__init__(
            self,
            SDKConfiguration(
                client=client,
                client_supplied=client_supplied,
                async_client=async_client,
                async_client_supplied=async_client_supplied,
                security=security,
                server_url=server_url,
                server=server,
                retry_config=retry_config,
                timeout_ms=timeout_ms,
                debug_logger=debug_logger,
            ),
            parent_ref=self,
        )

        hooks = SDKHooks()

        # pylint: disable=protected-access
        self.sdk_configuration.__dict__["_hooks"] = hooks

        current_server_url, *_ = self.sdk_configuration.get_server_details()
        server_url, self.sdk_configuration.client = hooks.sdk_init(
            current_server_url, client
        )
        if current_server_url != server_url:
            self.sdk_configuration.server_url = server_url

        weakref.finalize(
            self,
            close_clients,
            cast(ClientOwner, self.sdk_configuration),
            self.sdk_configuration.client,
            self.sdk_configuration.client_supplied,
            self.sdk_configuration.async_client,
            self.sdk_configuration.async_client_supplied,
        )

    def dynamic_import(self, modname, retries=3):
        for attempt in range(retries):
            try:
                return importlib.import_module(modname)
            except KeyError:
                # Clear any half-initialized module and retry
                sys.modules.pop(modname, None)
                if attempt == retries - 1:
                    break
        raise KeyError(f"Failed to import module '{modname}' after {retries} attempts")

    def __getattr__(self, name: str):
        if name in self._sub_sdk_map:
            module_path, class_name = self._sub_sdk_map[name]
            try:
                module = self.dynamic_import(module_path)
                klass = getattr(module, class_name)
                instance = klass(self.sdk_configuration, parent_ref=self)
                setattr(self, name, instance)
                return instance
            except ImportError as e:
                raise AttributeError(
                    f"Failed to import module {module_path} for attribute {name}: {e}"
                ) from e
            except AttributeError as e:
                raise AttributeError(
                    f"Failed to find class {class_name} in module {module_path} for attribute {name}: {e}"
                ) from e

        raise AttributeError(
            f"'{type(self).__name__}' object has no attribute '{name}'"
        )

    def __dir__(self):
        default_attrs = list(super().__dir__())
        lazy_attrs = list(self._sub_sdk_map.keys())
        return sorted(list(set(default_attrs + lazy_attrs)))

    def __enter__(self):
        return self

    async def __aenter__(self):
        return self

    def __exit__(self, exc_type, exc_val, exc_tb):
        if (
            self.sdk_configuration.client is not None
            and not self.sdk_configuration.client_supplied
        ):
            self.sdk_configuration.client.close()
        self.sdk_configuration.client = None

    async def __aexit__(self, exc_type, exc_val, exc_tb):
        if (
            self.sdk_configuration.async_client is not None
            and not self.sdk_configuration.async_client_supplied
        ):
            await self.sdk_configuration.async_client.aclose()
        self.sdk_configuration.async_client = None
